@@ -1,9 +1,7 @@
-from __future__ import annotations
-
 import logging
 import warnings
 from numbers import Number
-from typing import Union, Sequence, Optional, TYPE_CHECKING
+from typing import Union, Sequence, Optional, TYPE_CHECKING, Tuple
 from multiprocessing import cpu_count
 import random
 
@@ -153,6 +151,49 @@ class Volume:
             out = self._impl.contains_many_threaded(coords.tolist(), threads)
         return np.array(out, dtype=bool)
 
+    def intersections(
+        self, src_points: ArrayLike2D, tgt_points: ArrayLike2D
+    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
+        """Get intersections between line segments and volume.
+
+        Line segments are defined by their start (source) and end (target) points.
+        Only the first intersection for a given line segment is reported.
+
+        The output arrays are:
+
+        * Which line segment the intersection refers to,
+          as an index into the argument arrays
+        * The point of intersection
+        * Whether the intersection is with the inside face of the mesh
+
+        N.B. the inside face check will report True
+        for cases where a line touches ("skims") an external edge.
+
+        :param src_points: Nx3 array-like
+        :param tgt_points: Nx3 array-like
+        :raises ValueError: Inputs have different shapes or are not Nx3
+        :return: tuple of
+          uint array of indices (N),
+          float array of locations (Nx3),
+          bool array of is_backface (N)
+        """
+        src = np.asarray(src_points, self.dtype)
+        tgt = np.asarray(tgt_points, self.dtype)
+
+        if src.shape != tgt.shape:
+            raise ValueError("Source and target points arrays must be the same shape")
+
+        if src.shape[1:] != (3,):
+            raise ValueError("Points must be Nx3 array-like")
+
+        idxs, points, bfs = self._impl.intersections(src.tolist(), tgt.tolist())
+
+        return (
+            np.array(idxs, np.uint64),
+            np.array(points, self.dtype),
+            np.array(bfs, bool),
+        )
+
     @classmethod
     def from_meshio(
         cls,
@@ -161,15 +202,15 @@ class Volume:
         threads=None,
         n_rays=DEFAULT_RAYS,
         ray_seed=None,
-    ) -> Volume:
+    ) -> "Volume":
         """
         Convenience function for instantiating a Volume from a meshio Mesh.
 
         :param mesh: meshio Mesh whose only cells are triangles.
-        :param validate: as passed to __init__, defaults to False
-        :param threads: as passed to __init__, defaults to None
-        :param n_rays: as passed to __init__, defaults to 3
-        :param ray_seed: as passed to __init__, defaults to None (random)
+        :param validate: as passed to ``__init__``, defaults to False
+        :param threads: as passed to ``__init__``, defaults to None
+        :param n_rays: as passed to ``__init__``, defaults to 3
+        :param ray_seed: as passed to ``__init__``, defaults to None (random)
         :raises ValueError: if Mesh does not have triangle cells
         :return: Volume instance
         """
@@ -183,7 +224,7 @@ class Volume:
     @property
     def points(self) -> np.ndarray:
         """
-        Nx3 array of float32 describing vertices
+        Nx3 array of float describing vertices
         """
         return np.array(self._impl.points(), self.dtype)
 
@@ -196,11 +237,10 @@ class Volume:
 
     @property
     def extents(self) -> np.ndarray:
-        """
-        [
-            [xmin, ymin, zmin],
-            [xmax, ymax, zmax],
-        ]
+        """Axis-aligned bounding box of the volume.
+
+        :return: 2x3 numpy array of floats,
+          where the first row is mins and the second row is maxes.
         """
         return np.array(self._impl.aabb(), self.dtype)
 
