@@ -1,5 +1,4 @@
 import numpy as np
-import trimesh
 
 import meshio
 import pytest
@@ -193,7 +192,7 @@ def check_internals_equal(expected, actual):
     assert np.array_equal(expected, actual)
 
 
-def test_trimesh(trimesh_volume: trimesh.Trimesh, sample_points, expected, benchmark):
+def test_trimesh(trimesh_volume, sample_points, expected, benchmark):
     actual = benchmark(trimesh_volume.contains, sample_points)
     check_internals_equal(expected, actual)
 
@@ -223,7 +222,12 @@ def test_ncollpyde(mesh, n_rays, sample_points, expected, benchmark):
 #     benchmark(sez_right.contains, sample_points, threads=THREADS)
 
 
-@pytest.mark.xfail(reason="Results do not match yet")
-def test_pyoctree(pyoctree_volume: PyOctreeWrapper, sample_points, expected, benchmark):
-    actual = benchmark(pyoctree_volume.contains, sample_points)
-    check_internals_equal(expected, actual)
+@pytest.mark.parametrize("safe", [True, False], ids=lambda x: ["FAST", "SAFE"][int(x)])
+def test_pyoctree(
+    pyoctree_volume: PyOctreeWrapper, safe, sample_points, expected, benchmark
+):
+    actual = benchmark(pyoctree_volume.contains, sample_points, safe)
+    if safe:
+        check_internals_equal(expected, actual)
+    else:
+        pytest.xfail("pyoctree results are not consistent unless in SAFE mode")
